#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class gaussian_factor(Real):
    """
    Set a factor for the gaussian kernel for node-based averaging.~%Large values give small size, small values give large size of kernel.
    """

    fluent_name = "gaussian-factor"

    return_type = "<object object at 0x7f0b2d2052d0>"
