#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class fixed_time_step_count(Integer):
    """
     Set Number of Fixed Time Steps.
    """

    fluent_name = "fixed-time-step-count"

    return_type = "<object object at 0x7f0b2c2e0400>"
