#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .command_name import command_name as command_name_cls

class delete(CommandWithPositionalArgs):
    """
    Delete an execute-command.
    
    Parameters
    ----------
        command_name : str
            'command_name' child.
    
    """

    fluent_name = "delete"

    argument_names = \
        ['command_name']

    _child_classes = dict(
        command_name=command_name_cls,
    )

    return_type = "<object object at 0x7fad5c84a4b0>"
