#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .banded_coloring import banded_coloring as banded_coloring_cls
from .number_of_bands import number_of_bands as number_of_bands_cls

class coloring(Group):
    """
    Select coloring option.
    """

    fluent_name = "coloring"

    child_names = \
        ['banded_coloring', 'number_of_bands']

    _child_classes = dict(
        banded_coloring=banded_coloring_cls,
        number_of_bands=number_of_bands_cls,
    )

    return_type = "<object object at 0x7fad5c941cd0>"
