#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class sbes_update_interval_k_omega(Integer):
    """
    Set an integer value how often the k and omega equations are updated in a transient SBES run.
    """

    fluent_name = "sbes-update-interval-k-omega"

    return_type = "<object object at 0x7fad5e815520>"
