#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .thermal_bc import thermal_bc as thermal_bc_cls
from .temperature import temperature as temperature_cls
from .q import q as q_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['thermal_bc', 'temperature', 'q']

    _child_classes = dict(
        thermal_bc=thermal_bc_cls,
        temperature=temperature_cls,
        q=q_cls,
    )

    return_type = "<object object at 0x7f8327cc43a0>"
